﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using Rhino.Commons.HttpModules;
using Castle.Windsor;
using Rhino.Commons;
using Microdesk.SkillPortal.DomainPersistence;
using Microdesk.SkillPortal.DomainServices;

namespace SkillPortalSite
{
    // Note: For instructions on enabling IIS6 or IIS7 classic mode, 
    // visit http://go.microsoft.com/?LinkId=9394801

    public class MvcApplication : UnitOfWorkApplication   //System.Web.HttpApplication
    {
        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");

            routes.MapRoute(
                "Default",                                              // Route name
                "{controller}/{action}/{id}",                           // URL with parameters
                new { controller = "Home", action = "Index", id = "" }  // Parameter defaults
            );

        }



        public override void Application_Start(object sender, EventArgs e)
        {
            base.Application_Start(sender, e);
            RegisterRoutes(RouteTable.Routes);

            ControllerBuilder.Current.SetControllerFactory(typeof(RhinoIoCControllerFactory));


        }



        protected override IWindsorContainer CreateContainer(string windsorConfig)
        {
            IWindsorContainer container = new WindsorContainer();
            container.AddComponent<IUnitOfWorkFactory, NHibernateUnitOfWorkFactory>();

            container.AddComponent<ISkillTypeRepository, SkillTypeRepository>();
            container.AddComponent<IUserService, UserService>();
            container.AddComponent<IEmployeeRepository, EmployeeRepository>();

            //container.AddComponent<Controllers.HomeController, Controllers.HomeController>();
            //container.AddComponent<Controllers.AccountController, Controllers.AccountController>();

            System.Reflection.Assembly assy = new Controllers.HomeController().GetType().Assembly;

            foreach (Type type in assy.GetTypes())
            {
                if (typeof(IController).IsAssignableFrom(type) && !type.IsAbstract)
                {
                    container.AddComponent(type.Name.ToUpper(), type);
                }
            }

            return container;
        }


        public class RhinoIoCControllerFactory : IControllerFactory
        {

            public IController CreateController(RequestContext requestContext, string controllerName)
            {
                return IoC.Resolve<IController>((controllerName + "Controller").ToUpper());
            }

            public void ReleaseController(IController controller)
            {
                IoC.Container.Release(controller);
            }

        }

    }



}