﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;
using System.Web.Mvc;
using SkillPortalSite.Controllers;
using Microdesk.SkillPortal.DomainModel;
using Rhino.Mocks;
using Microdesk.SkillPortal.DomainPersistence;
using Rhino.Commons;
using Microdesk.SkillPortal.DomainServices;

namespace ControllerTests
{
    [TestFixture]
    public class ExployeeControllerTests
    {

        private IDisposable _registerGlobalUnitOfWork;
        [SetUp]
        public void Setup()
        {
            var unitOfWork = MockRepository.GenerateStub<IUnitOfWork>();

            _registerGlobalUnitOfWork = UnitOfWork.RegisterGlobalUnitOfWork(unitOfWork);

        }

        [TearDown]
        public void TearDown()
        {
            _registerGlobalUnitOfWork.Dispose();
        }


        [Test]
        public void CanReturnListOfSkillTypes()
        {
            var skillTypeRepos = MockRepository.GenerateMock<ISkillTypeRepository>();

            skillTypeRepos.Expect(x => x.GetAllSkills()).Return(new List<SkillType>());

            var userService = MockRepository.GenerateStub<IUserService>();

            var employeeRepository = MockRepository.GenerateStub<IEmployeeRepository>();

            EmployeeController employeeController = new EmployeeController(skillTypeRepos, userService, employeeRepository);

            ViewResult result = employeeController.SelectSkills();

            Assert.IsNotNull(result.ViewData.Model as IList<SkillType>);

            Assert.AreEqual("SelectSkills", result.ViewName);

        }


        [Test]
        public void CanAddSkillsToEmployee()
        {
            Guid newGuid1 = new Guid("11111111-1111-1111-1111-111111111111");
            Guid newGuid2 = new Guid("22222222-2222-2222-2222-222222222222");
            
            var skillTypeRepository = MockRepository.GenerateStub<ISkillTypeRepository>();

            skillTypeRepository.Expect(x => x.GetSkillType(newGuid1)).Return(new SkillType());
            skillTypeRepository.Expect(x => x.GetSkillType(newGuid2)).Return(new SkillType());

            var userService = MockRepository.GenerateStub<IUserService>();

            Employee theEmployee = new Employee();

            userService.Expect(x => x.GetEmployeeForCurrentUser()).Return(theEmployee);

            var employeeRepository = MockRepository.GenerateStub<IEmployeeRepository>();

            EmployeeController employeeController = new EmployeeController(skillTypeRepository, userService, employeeRepository);


            Guid[] theGuids = { newGuid1, newGuid2 };

            employeeController.SelectSkills(theGuids);

            Assert.AreEqual(2, theEmployee.Skills.Count);
            
        }


    }
}
